@@ -1,33 +1,33 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2005 Hamish Rodda <rodda@kde.org>
- *  Copyright (C) 2008-2018 Dominik Haumann <dhaumann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2005 Hamish Rodda <rodda@kde.org>
+    Copyright (C) 2008-2018 Dominik Haumann <dhaumann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "katelayoutcache.h"
 
 #include <QtAlgorithms>
 
+#include "katebuffer.h"
+#include "katedocument.h"
+#include "katepartdebug.h"
 #include "katerenderer.h"
 #include "kateview.h"
-#include "katedocument.h"
-#include "katebuffer.h"
-#include "katepartdebug.h"
 
 namespace
 {
